/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.cts.emptydeviceowner;

import android.app.admin.DeviceAdminReceiver;
import android.app.admin.DevicePolicyManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

public class DeviceOwnerChangedReceiver extends DeviceAdminReceiver {

	@Override
	public void onReceive(Context context, Intent intent) {
		Log.d("DeviceOwnerChangedReceiver", "device owner is changed.");
		if (!DevicePolicyManager.ACTION_DEVICE_OWNER_CHANGED.equals(intent.getAction())) {
			return;
		}
		DevicePolicyManager dpm = context.getSystemService(DevicePolicyManager.class);
		if (!dpm.isDeviceOwnerApp(context.getPackageName())) {
			return;
		}
		Log.d("DeviceOwnerChangedReceiver", "transferring ownership to CtsVerifier");
		dpm.transferOwnership(
			EmptyDeviceAdmin.getComponentName(context),
			new ComponentName("com.android.cts.verifier",
				"com.android.cts.verifier.managedprovisioning.DeviceAdminTestReceiver"),
			null);
	}
}
